package de.intevation.mxd.reader;

import java.io.IOException;

import java.awt.Color;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.MultiLayerLineSymbol;
import com.esri.arcgis.display.SimpleLineSymbol;
import com.esri.arcgis.display.MarkerLineSymbol;
import com.esri.arcgis.display.PictureLineSymbol;
import com.esri.arcgis.display.CartographicLineSymbol;
import com.esri.arcgis.display.esriSimpleMarkerStyle;
import com.esri.arcgis.display.IRgbColor;
import com.esri.arcgis.display.RgbColor;

import org.w3c.dom.Element;
import de.intevation.mxd.utils.MapToXMLUtils;

/**
 * Reads multi layer line symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class MultiLayerLineSymbolReader implements ISymbolReader{

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(MultiLayerLineSymbolReader.class);

    /**
     * Private member.
     */
    private Element renderer;
    private MultiLayerLineSymbol symbol;
    private MapToXMLUtils util;


    public MultiLayerLineSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof MultiLayerLineSymbol) {
            this.symbol = (MultiLayerLineSymbol)symbol;
        }
        else {
            throw new Exception("Not a MultiLayerLineSymbol!");
        }
    }

    /**
     * Setter for the parent XML element.
     *
     * @param parent The XML parent node.
     */
    public void setParent(Element parent) {
        this.renderer = parent;
    }

    /**
     * Setter for XML document helper.
     *
     * @param util The helper class for storing map information.
     */
    public void setUtil(MapToXMLUtils util) {
        this.util = util;
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws IOException {
        logger.debug("read()");
        for(int i = 0; i < symbol.getLayerCount(); i++) {
            try {
                ISymbol sym = (ISymbol)symbol.getLayer(i);

                if(sym instanceof SimpleLineSymbol) {
                    ISymbolReader sreader = new SimpleLineSymbolReader(sym);
                    sreader.setParent(renderer);
                    sreader.setUtil(util);
                    sreader.read();
                }
                else if(sym instanceof MarkerLineSymbol) {
                    ISymbolReader sreader = new MarkerLineSymbolReader(sym);
                    sreader.setParent(renderer);
                    sreader.setUtil(util);
                    sreader.read();
                }
                else if(sym instanceof PictureLineSymbol) {
                    ISymbolReader sreader = new PictureLineSymbolReader(sym);
                    sreader.setParent(renderer);
                    sreader.setUtil(util);
                    sreader.read();
                }
                else if(sym instanceof CartographicLineSymbol) {
                    ISymbolReader sreader = new CartoLineSymbolReader(sym);
                    sreader.setParent(renderer);
                    sreader.setUtil(util);
                    sreader.read();
                }
                else {
                    logger.debug("The type of " + sym.getClass().toString() +
                                 " is not implemented!");
                    System.out.println(
                            "No known instance: " + sym.getClass().toString());
                }
            }
            catch(Exception e) {
                e.printStackTrace();
                return null;
            }
        }
        return renderer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
